[llvm-commits] [llvm] r58386 - in /llvm/trunk/lib/CodeGen/SelectionDAG: LegalizeTypes.cpp LegalizeTypes.h

Duncan Sands baldrick at free.fr
Wed Oct 29 10:52:12 PDT 2008


Author: baldrick
Date: Wed Oct 29 12:52:12 2008
New Revision: 58386

URL: http://llvm.org/viewvc/llvm-project?rev=58386&view=rev
Log:
Uniformize capitalization of NodeId.

Modified:
    llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp
    llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.h

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp?rev=58386&r1=58385&r2=58386&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp Wed Oct 29 12:52:12 2008
@@ -31,7 +31,7 @@
   // done.  Set it to null to avoid confusion.
   DAG.setRoot(SDValue());
 
-  // Walk all nodes in the graph, assigning them a NodeID of 'ReadyToProcess'
+  // Walk all nodes in the graph, assigning them a NodeId of 'ReadyToProcess'
   // (and remembering them) if they are leaves and assigning 'NewNode' if
   // non-leaves.
   for (SelectionDAG::allnodes_iterator I = DAG.allnodes_begin(),
@@ -140,25 +140,25 @@
     for (SDNode::use_iterator UI = N->use_begin(), E = N->use_end();
          UI != E; ++UI) {
       SDNode *User = *UI;
-      int NodeID = User->getNodeId();
-      assert(NodeID != ReadyToProcess && NodeID != Processed &&
+      int NodeId = User->getNodeId();
+      assert(NodeId != ReadyToProcess && NodeId != Processed &&
              "Invalid node id for user of unprocessed node!");
 
       // This node has two options: it can either be a new node or its Node ID
       // may be a count of the number of operands it has that are not ready.
-      if (NodeID > 0) {
-        User->setNodeId(NodeID-1);
+      if (NodeId > 0) {
+        User->setNodeId(NodeId-1);
 
         // If this was the last use it was waiting on, add it to the ready list.
-        if (NodeID-1 == ReadyToProcess)
+        if (NodeId-1 == ReadyToProcess)
           Worklist.push_back(User);
         continue;
       }
 
       // Otherwise, this node is new: this is the first operand of it that
-      // became ready.  Its new NodeID is the number of operands it has minus 1
+      // became ready.  Its new NodeId is the number of operands it has minus 1
       // (as this node is now processed).
-      assert(NodeID == NewNode && "Unknown node ID!");
+      assert(NodeId == NewNode && "Unknown node ID!");
       User->setNodeId(User->getNumOperands()-1);
 
       // If the node only has a single operand, it is now ready.
@@ -340,7 +340,7 @@
 
 
 /// ReplaceValueWith - The specified value was legalized to the specified other
-/// value.  If they are different, update the DAG and NodeIDs replacing any uses
+/// value.  If they are different, update the DAG and NodeIds replacing any uses
 /// of From to use To instead.
 void DAGTypeLegalizer::ReplaceValueWith(SDValue From, SDValue To) {
   if (From == To) return;

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.h?rev=58386&r1=58385&r2=58386&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.h (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/LegalizeTypes.h Wed Oct 29 12:52:12 2008
@@ -35,9 +35,9 @@
   TargetLowering &TLI;
   SelectionDAG &DAG;
 public:
   // NodeIDFlags - This pass uses the NodeID on the SDNodes to hold information
   // about the state of the node.  The enum has all the values.
-  enum NodeIDFlags {
+  enum NodeIdFlags {
     /// ReadyToProcess - All operands have been processed, so this node is ready
     /// to be handled.
     ReadyToProcess = 0,
@@ -153,7 +153,7 @@
 
   void run();
 
-  /// ReanalyzeNode - Recompute the NodeID and correct processed operands
+  /// ReanalyzeNode - Recompute the NodeId and correct processed operands
   /// for the specified node, adding it to the worklist if ready.
   void ReanalyzeNode(SDNode *N) {
     N->setNodeId(NewNode);
@@ -35,9 +35,9 @@
   SelectionDAG &DAG;
 public:
-  // NodeIDFlags - This pass uses the NodeID on the SDNodes to hold information
+  // NodeIdFlags - This pass uses the NodeId on the SDNodes to hold information
   // about the state of the node.  The enum has all the values.





More information about the llvm-commits mailing list